@@ -7,9 +7,10 @@ from avlos.unit_field import UnitField
 from avlos.datatypes import DataTypeField
 from avlos.mixins.comm_node import CommNode
 from avlos.mixins.named_node import NamedNode
+from avlos.mixins.meta_node import MetaNode
 
 
-class RemoteFunction(CommNode, NamedNode):
+class RemoteFunction(CommNode, NamedNode, MetaNode):
     """
     Remote Function with zero or more arguments, return
     type, parent and a comms channel
@@ -25,9 +26,11 @@ class RemoteFunction(CommNode, NamedNode):
         unit=None,
         rst_target=None,
         ep_id=-1,
+        meta={},
     ):
         CommNode.__init__(self)
         NamedNode.__init__(self, name)
+        MetaNode.__init__(self, meta_dict=meta)
         self.summary = summary
         self.dtype = dtype
         self.unit = unit
