@@ -1,10 +1,11 @@
 from functools import cached_property
 
-class NamedNode:
 
-    def __init__(self, name):
+class NamedNode:
+    def __init__(self, name, include_base_name=False):
         self._parent = None
         self.name = name
+        self.include_base_name = include_base_name
 
     # this kinda stinks, cause it is implemented elsewhere
     # @cached_property
@@ -14,6 +15,8 @@ class NamedNode:
     @cached_property
     def full_name(self):
         try:
-            return "{}.{}".format(self._parent.full_name, self.name)
+            return "{}.{}".format(self._parent.full_name, self.name).strip(".")
         except AttributeError:
-            return self.name
\ No newline at end of file
+            if self.include_base_name:
+                return self.name
+            return ""
